package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeAction;
import java.io.File;
import java.io.FileInputStream;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.regex.Pattern;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.WorkbookFactory;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/AfterLoanExcelParseAction.class */
public class AfterLoanExcelParseAction extends LifeAction {
    private String uploadFile;
    private String fields;
    private static String AFTERLOANEXCEL_PARSE_COMPONENT = "【【贷后管理EXCEL数据解析】】";
    private static final String ERROR_CODE = "ALEPERR0001";
    private static final String AMT_REGEX = "^((-)?\\d{1,8}(\\.\\d{1,20})?)$";
    private static final String RATE_REGEX = "^(\\d{1,2}(\\.\\d{1,20})?)$";
    private static final String ASSET_LIABILITY_RATE_REGEX = "^((-)?\\d{1,2}(\\.\\d{1,20})?)$";
    private static final String INCOME_RATE_REGEX = "^(\\d{1,8}(\\.\\d{1,20})?)$";
    private static final String DATE_REGEX = "^((\\d{2}(([02468][048])|([13579][26]))[\\-\\/\\s]?((((0?[13578])|(1[02]))[\\-\\/\\s]?((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-\\/\\s]?((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-\\/\\s]?((0?[1-9])|([1-2][0-9])))))|(\\d{2}(([02468][1235679])|([13579][01345789]))[\\-\\/\\s]?((((0?[13578])|(1[02]))[\\-\\/\\s]?((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-\\/\\s]?((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-\\/\\s]?((0?[1-9])|(1[0-9])|(2[0-8]))))))";
    private String errorMsg = "";

    public String execute(Context context) throws GENEException {
        this.errorMsg = "";
        try {
            String[] fieldArray = this.fields.toString().split("\\|\\|");
            String filePathName = (String) context.get(this.uploadFile);
            Sheet sheet = WorkbookFactory.create(new FileInputStream(new File(filePathName))).getSheetAt(0);
            int rowNum = sheet.getPhysicalNumberOfRows();
            int columnNum = sheet.getRow(0).getPhysicalNumberOfCells();
            int fieldNum = fieldArray.length / 2;
            if (rowNum - 1 < fieldNum || columnNum != 3) {
                GENELog.log(AFTERLOANEXCEL_PARSE_COMPONENT, GENELog.INFO, 0, "EXCEL模板错误");
                this.errorMsg = "EXCEL模板错误";
                throw new GENEException(ERROR_CODE, "EXCEL模板错误");
            }
            for (int i = 0; i <= fieldNum; i++) {
                Row row = sheet.getRow(i);
                if (i == 0 || i == 18) {
                    if (i == 0) {
                        context.put(fieldArray[0], handleDateValue(getCellValue(row.getCell(1))));
                        context.put(fieldArray[1], handleDateValue(getCellValue(row.getCell(2))));
                    } else {
                        context.put(fieldArray[(2 * i) - 2], handleDateValue(getCellValue(row.getCell(1))));
                        context.put(fieldArray[(2 * i) - 1], handleDateValue(getCellValue(row.getCell(2))));
                    }
                } else if (i != 1) {
                    if (i == 9 || i == 14 || i == 20 || i == 21 || i == 22 || i == 26) {
                        context.put(fieldArray[(2 * i) - 2], handleValue(getCellValue(row.getCell(1)), 2, i));
                        context.put(fieldArray[(2 * i) - 1], handleValue(getCellValue(row.getCell(2)).trim(), 2, i));
                    } else {
                        context.put(fieldArray[(2 * i) - 2], handleValue(getCellValue(row.getCell(1)).trim(), 1, i));
                        context.put(fieldArray[(2 * i) - 1], handleValue(getCellValue(row.getCell(2)).trim(), 1, i));
                    }
                }
            }
            return "0";
        } catch (Exception e) {
            GENELog.log(AFTERLOANEXCEL_PARSE_COMPONENT, GENELog.INFO, 0, "EXCEL解析失败:".concat(String.valueOf(e)));
            if (this.errorMsg != null && !this.errorMsg.equals("")) {
                throw new GENEException(ERROR_CODE, this.errorMsg, e);
            }
            throw new GENEException(ERROR_CODE, "EXCEL解析异常", e);
        }
    }

    public String getCellValue(Cell cell) throws Exception {
        String str;
        if (cell != null) {
            int rowIndex = cell.getRowIndex() + 1;
            int columnIndex = cell.getColumnIndex() + 1;
            try {
                switch (cell.getCellType()) {
                    case 0:
                        if (DateUtil.isCellDateFormatted(cell)) {
                            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                            Date date = cell.getDateCellValue();
                            str = sdf.format(date);
                            break;
                        } else {
                            cell.setCellType(1);
                            str = cell.getStringCellValue();
                            break;
                        }
                    case 1:
                        str = cell.getStringCellValue();
                        break;
                    case 2:
                    default:
                        cell.setCellType(1);
                        str = cell.getStringCellValue();
                        break;
                    case 3:
                        str = "";
                        break;
                    case 4:
                        str = String.valueOf(cell.getBooleanCellValue());
                        break;
                }
            } catch (Exception e) {
                this.errorMsg = "第" + rowIndex + "行第" + columnIndex + "列数据格式错误！";
                throw e;
            }
        } else {
            str = "";
        }
        return str.replace(" ", "");
    }

    private String handleValue(String value, int type, int i) {
        boolean isMatch;
        String errorNote;
        String result;
        int scaleNum;
        if (value.equals("")) {
            return "";
        }
        if (type == 1) {
            isMatch = Pattern.matches(AMT_REGEX, value);
            errorNote = "最多输入8位整数，2位小数";
        } else if (i == 9) {
            isMatch = Pattern.matches(ASSET_LIABILITY_RATE_REGEX, value);
            errorNote = "最多输入4位整数，4位小数";
        } else if (i == 22) {
            isMatch = Pattern.matches(INCOME_RATE_REGEX, value);
            errorNote = "最多输入10位正整数，4位小数";
        } else {
            isMatch = Pattern.matches(RATE_REGEX, value);
            errorNote = "最多输入4位正整数，4位小数";
        }
        if (isMatch) {
            BigDecimal bigDecimal = new BigDecimal(value);
            if (type == 2) {
                BigDecimal hundredValue = bigDecimal.multiply(new BigDecimal(100));
                int scaleNum2 = hundredValue.scale();
                if (scaleNum2 > 6) {
                    scaleNum = 4;
                } else if (scaleNum2 > 2) {
                    scaleNum = scaleNum2 - 2;
                } else {
                    scaleNum = 0;
                }
                result = hundredValue.setScale(scaleNum, 4).toString();
            } else {
                int scale = bigDecimal.scale();
                int scaleNum3 = scale;
                if (scale > 2) {
                    scaleNum3 = 2;
                }
                result = bigDecimal.setScale(scaleNum3, 4).toString();
            }
        } else {
            result = errorNote;
        }
        return result;
    }

    private String handleDateValue(String value) {
        String result;
        if (Pattern.matches(DATE_REGEX, value)) {
            result = value;
        } else {
            result = "格式错误";
        }
        return result;
    }

    public void setUploadFile(String uploadFile) {
        this.uploadFile = uploadFile;
    }

    public void setFields(String fields) {
        this.fields = fields;
    }
}
